## Summary

Describe the change and why it was needed.

## Validation

- [ ] `uv run ruff check .`
- [ ] `uv run mypy src`
- [ ] `uv run pytest`
- [ ] `uv run python -m build`

## Risk

Describe rollout and rollback considerations.

## Documentation

- [ ] Updated docs for behavior/schema/CLI changes.
